#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 async
version:              2.2.6
visibility:           public
id:                   async-2.2.6-FyNZXdji95t98VleCj3HXu
key:                  async-2.2.6-FyNZXdji95t98VleCj3HXu
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2012
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
homepage:             https://github.com/simonmar/async
synopsis:             Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.

    Using @Async@ is safer than using threads in two
    ways:

    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.

    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').

category:             Concurrency
abi:                  8c0ae223270db8e5519465b1630b1470
exposed:              True
exposed-modules:
    Control.Concurrent.Async Control.Concurrent.Async.Internal
    Control.Concurrent.Async.Warden Control.Concurrent.Stream

import-dirs:          /usr/lib/ghc-9.6.6/site-local/async-2.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/async-2.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/async-2.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-async
hs-libraries:         HSasync-2.2.6-FyNZXdji95t98VleCj3HXu
depends:
    base-4.18.2.1 hashable-1.4.7.0-Eia1GH7GKUH7V9HVPMehAJ stm-2.5.1.0
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo

haddock-interfaces:   /usr/share/doc/haskell-async/html/async.haddock
haddock-html:         /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

